@@ -29,7 +29,7 @@ class Get_ASM_Consume:
                     # 如果不是今天或者昨天的日报文件，就删除；
                     os.system('rm -rf %s/%s' % (self.file_path, now_file_name))
 
-    def asm_login(self, company_name=''):
+    def asm_login(self):
         # 模拟网页请求；
         url = 'https://idmsa.apple.com/appleauth/auth/signin?isRememberMeEnabled=true'
         payload = {
@@ -97,23 +97,6 @@ class Get_ASM_Consume:
                         self.res_token_cm = session.cookies.get_dict()['XSRF-TOKEN-CM']
                         print('...正在获取Token...')
                         print('当前Token：%s' %(self.res_token_cm))
-
-                        if len(company_name) > 0:
-                            url = 'https://app-ads.apple.com/cm/api/v1/startup/orgs'
-                            headers = {
-                                'Host': 'app-ads.apple.com',
-                                'Connection': 'keep-alive',
-                                'Content-Type': 'application/json;charset=UTF-8',
-                                'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/84.0.4147.89 Safari/537.36',
-                                'X-XSRF-TOKEN-CM': self.res_token_cm
-                            }
-                            res = session.get(url, headers=headers)
-                            for org_info in res.json()['data']['orgDetails']:
-                                if org_info['name'] == company_name:
-                                    s = requests.cookies.RequestsCookieJar()
-                                    s.set('searchads.soid', org_info['id'])
-                                    session.cookies.update(s)
-                                    break
                         # 返回token；
                         return self.res_token_cm
                     else:
@@ -338,10 +321,26 @@ class Get_ASM_Consume:
             dingding_push.status_push()
             return '...登陆异常，请重试...'
 
-    def get_asm_fileList(self):
+    def get_asm_fileList(self, company_name=''):
         """
             * 获取中国区ASA账号上提交的资料列表及数据；
         """
+        if len(company_name) > 0:
+            url = 'https://app-ads.apple.com/cm/api/v1/startup/orgs'
+            headers = {
+                'Host': 'app-ads.apple.com',
+                'Connection': 'keep-alive',
+                'Content-Type': 'application/json;charset=UTF-8',
+                'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/84.0.4147.89 Safari/537.36',
+                'X-XSRF-TOKEN-CM': self.res_token_cm
+            }
+            res = session.get(url, headers=headers)
+            for org_info in res.json()['data']['orgDetails']:
+                if org_info['name'] == company_name:
+                    s = requests.cookies.RequestsCookieJar()
+                    s.set('searchads.soid', org_info['id'])
+                    session.cookies.update(s)
+                    break
         url = 'https://app-ads.apple.com/cm/api/v1/doc/find'
         offset_num = 0
         res_list = []
@@ -377,10 +376,26 @@ class Get_ASM_Consume:
                 break
         return res_list
 
-    def get_asm_resStatus(self):
+    def get_asm_resStatus(self, company_name=''):
         """
             * 获取中国区ASA账号审核状态列表；
         """
+        if len(company_name) > 0:
+            url = 'https://app-ads.apple.com/cm/api/v1/startup/orgs'
+            headers = {
+                'Host': 'app-ads.apple.com',
+                'Connection': 'keep-alive',
+                'Content-Type': 'application/json;charset=UTF-8',
+                'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/84.0.4147.89 Safari/537.36',
+                'X-XSRF-TOKEN-CM': self.res_token_cm
+            }
+            res = session.get(url, headers=headers)
+            for org_info in res.json()['data']['orgDetails']:
+                if org_info['name'] == company_name:
+                    s = requests.cookies.RequestsCookieJar()
+                    s.set('searchads.soid', org_info['id'])
+                    session.cookies.update(s)
+                    break
         url = 'https://app-ads.apple.com/cm/api/v1/approval/find'
         offset_num = 0
         res_list = []
